@@ -100,8 +100,11 @@ elif which assume-deploy-role.sh &> /dev/null && [ -z "$AWS_SESSION_TOKEN" ]; th
 fi
 
 eval "$(ndt session-to-env)"
+if [ -z "$NO_PULL"]; then
+   PULL="--pull"
+fi
 
-docker build -t "$DOCKER_NAME" --build-arg "AWS_ACCESS_KEY_ID=$AWS_ACCESS_KEY_ID"  --build-arg "AWS_SECRET_ACCESS_KEY=$AWS_SECRET_ACCESS_KEY" --build-arg "AWS_SESSION_TOKEN=$AWS_SESSION_TOKEN" "$component/docker-$ORIG_DOCKER_NAME"
+docker build $PULL -t "$DOCKER_NAME" --build-arg "AWS_ACCESS_KEY_ID=$AWS_ACCESS_KEY_ID"  --build-arg "AWS_SECRET_ACCESS_KEY=$AWS_SECRET_ACCESS_KEY" --build-arg "AWS_SESSION_TOKEN=$AWS_SESSION_TOKEN" "$component/docker-$ORIG_DOCKER_NAME"
 
 eval "$(ndt ecr-ensure-repo "$DOCKER_NAME")"
 docker tag $DOCKER_NAME:latest $DOCKER_NAME:$BUILD_NUMBER
