@@ -13,7 +13,9 @@ from dateutil.tz import tzutc
 
 from n_utils import _to_str
 from n_utils.bw_util import get_bwentry
+from n_utils.lp_util import get_lpentry
 from n_utils.az_util import az_select_subscription
+from n_utils.mfa_utils import mfa_generate_code
 
 
 def ConfigParser():
@@ -38,7 +40,7 @@ def read_expiring_profiles():
     return ret
 
 
-def read_profiles(prefix=None):
+def read_profiles(prefix=""):
     ret = []
     home = expanduser("~")
     credentials = join(home, ".aws", "credentials")
@@ -55,8 +57,11 @@ def read_profiles(prefix=None):
         with open(config) as configfile:
             parser.read_file(configfile)
             for profile in parser.sections():
-                if profile.startswith("profile ") and profile[8:] not in ret \
-                   and profile[8:].startswith(prefix):
+                if (
+                    profile.startswith("profile ")
+                    and profile[8:] not in ret
+                    and profile[8:].startswith(prefix)
+                ):
                     ret.append(profile[8:])
     return ret
 
@@ -110,11 +115,13 @@ def print_aws_profiles():
     parser = argparse.ArgumentParser(description=print_aws_profiles.__doc__)
     if "_ARGCOMPLETE" in os.environ:
         parser.add_argument(
-            "prefix", help="Prefix of profiles to print", default="", nargs='?'
+            "prefix", help="Prefix of profiles to print", default="", nargs="?"
         ).completer = ChoicesCompleter(read_profiles())
         argcomplete.autocomplete(parser)
     else:
-        parser.add_argument("prefix", help="Prefix of profiles to print", default="", nargs='?')
+        parser.add_argument(
+            "prefix", help="Prefix of profiles to print", default="", nargs="?"
+        )
     args = parser.parse_args()
     print(" ".join(read_profiles(prefix=args.prefix)))
 
@@ -276,15 +283,18 @@ def update_profile(profile, creds):
     with open(credentials, "w") as credfile:
         parser.write(credfile)
 
+
 def cli_profiles_to_json():
-    """ Prints aws config file contents as json for further parsing and use in other tools """
+    """Prints aws config file contents as json for further parsing and use in other tools"""
     parser = argparse.ArgumentParser(description=cli_profiles_to_json.__doc__)
     argcomplete.autocomplete(parser)
     _ = parser.parse_args()
     profiles_to_json()
 
+
 def profiles_to_json():
     from collections import OrderedDict
+
     home = expanduser("~")
     config = join(home, ".aws", "config")
     ret = OrderedDict()
@@ -300,6 +310,7 @@ def profiles_to_json():
                         section_data[option] = parser.get(section, option)
         print(json.dumps(ret, indent=2))
 
+
 def update_profile_conf(profile, creds):
     home = expanduser("~")
     config = join(home, ".aws", "config")
@@ -316,6 +327,7 @@ def update_profile_conf(profile, creds):
         parser.write(conffile)
     return
 
+
 def store_bw_profile(bw_entry_name):
     bw_entry = get_bwentry(bw_entry_name)
     if (
@@ -446,20 +458,22 @@ def enable_profile(profile_type, profile):
         if expiry < now:
             bw_prefix = ""
             bw_entry = None
+            lp_entry = None
             profile_data = get_profile(profile)
             if "bitwarden_entry" in profile_data and profile_data["bitwarden_entry"]:
                 bw_entry = get_bwentry(profile_data["bitwarden_entry"])
+            if "lastpass_entry" in profile_data and profile_data["lastpass_entry"]:
+                lp_entry = get_lpentry(profile_data["lastpass_entry"])
             if "AWS_SESSION_EXPIRATION_EPOC_" + safe_profile in os.environ:
                 print("unset AWS_SESSION_EXPIRATION_EPOC_" + safe_profile + ";")
             if profile_type == "azure":
                 gui_mode = ""
-                if (
-                    "azure_login_mode" in profile_data
-                    and profile_data["azure_login_mode"] == "gui"
-                ):
-                    gui_mode = " --mode=gui"
+                if "azure_login_mode" in profile_data:
+                    gui_mode = " --mode=" + profile_data["azure_login_mode"]
                 if bw_entry:
                     bw_prefix = "AZURE_DEFAULT_PASSWORD='" + bw_entry.password + "' "
+                elif lp_entry:
+                    bw_prefix = "AZURE_DEFAULT_PASSWORD='" + lp_entry.password + "' "
                 print(
                     bw_prefix
                     + "aws-azure-login --profile "
@@ -470,6 +484,8 @@ def enable_profile(profile_type, profile):
             elif profile_type == "adfs":
                 if bw_entry:
                     bw_prefix = "ADFS_DEFAULT_PASSWORD='" + bw_entry.password + "' "
+                elif lp_entry:
+                    bw_prefix = "ADFS_DEFAULT_PASSWORD='" + lp_entry.password + "' "
                 print(
                     bw_prefix + "adfs-aws-login --profile " + profile + " --no-prompt"
                 )
@@ -478,6 +494,14 @@ def enable_profile(profile_type, profile):
                     bw_prefix = "LASTPASS_DEFAULT_PASSWORD='" + bw_entry.password + "' "
                     if bw_entry.totp_now:
                         bw_prefix += "LASTPASS_DEFAULT_OTP='" + bw_entry.totp_now + "' "
+                elif lp_entry:
+                    bw_prefix = "LASTPASS_DEFAULT_PASSWORD='" + lp_entry.password + "' "
+                if "ndt_mfa_token" in profile_data:
+                    bw_prefix += (
+                        "LASTPASS_DEFAULT_OTP='"
+                        + mfa_generate_code(profile_data["ndt_mfa_token"])
+                        + "' "
+                    )
                 print(
                     bw_prefix
                     + "lastpass-aws-login --profile "
